@@ -5,6 +5,6 @@ use base qw/DBIx::Class::Schema/;
 
 no warnings qw/qw/;
 
-__PACKAGE__->load_classes(qw/ Test Test2/);
+__PACKAGE__->load_classes(qw/ Test /);
 
 1;
